@echo off
setlocal enabledelayedexpansion

set argCount=0
for %%x in (%*) do (
   set /A argCount+=1
   set "argVec[!argCount!]=%%~x"
)

rem Configuration:
rem --------------
rem The script must be configured with the correct DPI of the source images for the pdf pages to be correctly sized. 
rem Levels define the interval of brightness in the source file that will be used for fully black and white. 
rem A smaller number of colors will make the output compress better. A larger number of colors might look better. 

set DPI=300
set LEVELS=60%%,95%%
set COLORS=12

rem Help text

echo ImagesToPdf.bat v1.0 - Convert images to LZW compressed PDF
echo.
echo By Lars Ole Pontoppidan, read more: https://larsee.com
echo.
echo This script requires imagemagick and pdftk to be installed
echo.
echo Run the script with one or more source images files (eg. PNG) as command line parameters to convert to a high quality PDF document
echo.
echo Script configuration:
echo.
echo Source DPI : %DPI% 
echo Levels     : %LEVELS% 
echo Colors     : %COLORS%
echo.
echo Number of input files to process: %argCount%
echo.

pause

if %argCount% equ 0 exit

set pages=

for /L %%i in (1,1,%argCount%) do (
   echo magick convert "!argVec[%%i]!" -level !LEVELS! -colors !COLORS! -units PixelsPerInch image -density !DPI! -compress LZW "Page-%%i.pdf"
   magick convert "!argVec[%%i]!" -level !LEVELS! -colors !COLORS! -units PixelsPerInch image -density !DPI! -compress LZW "Page-%%i.pdf"
   set pages=!pages! "Page-%%i.pdf"
) 

echo pdftk %pages% cat output Output.pdf
pdftk %pages% cat output Output.pdf

